/*
 * This file is part of the KFTPGrabber project
 *
 * Copyright (C) 2003-2005 by the KFTPGrabber developers
 * Copyright (C) 2003-2005 Jernej Kos <kostko@jweb-network.net>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 * MA 02111-1307, USA.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 *
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
#ifndef KFTPSERVERMANAGEMENTDIALOG_H
#define KFTPSERVERMANAGEMENTDIALOG_H

#include <kdialogbase.h>

class QSpinBox;
class QLineEdit;
class QGridLayout;
class KPasswordEdit;

class KFTPServerManagementListViewItem;

enum Attribute {
  NO = 0, /**< false */
  YES, /**< true */
  OPTIONAL /**< optional */
};

/**
 * @author Blacknator
 *
 * @brief this class represents a dialog
 *
 * the dialog configures itself. it depends on the values, ip-addresses and names the user must enter
 * to execute the site command sucessfull
 */
class KFTPServerManagementDialog : public KDialogBase
{
Q_OBJECT

public:
    KFTPServerManagementDialog();
    ~KFTPServerManagementDialog();

    /**
     * shows a dialog if the user must enter something
     * @param item the item that was double clicked
     */
    void showDialog(KFTPServerManagementListViewItem *item);

signals:
    /**
     * the command is send if the dialog exit
     * connected to KFTPServerManagementListView::slotSendCommand(QString)
     * @param execute true if no error occured, otherwise the dialog is showing again
     * @param command command to send
     */
    void command(bool execute, QString command);

private:
    bool checkArguments();
    void createDialog();

private slots:
    /** ok button of the dialog was pressed */
    void slotSendCommand();

private:
    /** @brief the clicked item in the list view */
    KFTPServerManagementListViewItem *m_item;
    /** @brief the command to execute */
    QString m_command;

    /** @brief true - user must enter a value */
    Attribute m_value;
    /** @brief true - user must enter a username */
    Attribute m_user;
    /** @brief true - user must enter a group */
    Attribute m_group;
    /** @brief true - user must enter a description */
    Attribute m_description;
    /** @brief true - user must enter a password */
    Attribute m_password;

    /** @brief Dialog layout */
    QGridLayout *m_layout;

    /** @brief QLabel in the dialog - left besides the QSpinBox */
    QLabel *m_valueLabel;
    /** @brief QSpinBox in the dialog */
    QSpinBox *m_valueSpinBox;

    /** @brief QLabel in the dialog - left besides the QLineEdit */
    QLabel *m_userLabel;
    /** @brief QLineEdit in the dialog */
    QLineEdit *m_userEdit;

    /** @brief QLabel in the dialog - left besides the QLineEdit */
    QLabel *m_groupLabel;
    /** @brief QLineEdit in the dialog */
    QLineEdit *m_groupEdit;

    /** @brief QLabel in the dialog - left besides the QLineEdit */
    QLabel *m_descriptionLabel;
    /** @brief QLineEdit in the dialog */
    QLineEdit *m_descriptionEdit;

    /** @brief QLabel in the dialog - left besides the QLineEdit */
    QLabel *m_passwordLabel1;
    QLabel *m_passwordLabel2;
    /** @brief QLineEdit in the dialog */
    KPasswordEdit *m_passwordEdit1;
    KPasswordEdit *m_passwordEdit2;
};

#endif
